# Changelog

## [unreleased]

### Features

- Confirm before erase
- Newest changes with support for MNVe (PCIe)
- Info mismatch just shows a warning instead of exit
- Auto build release packages
- Builds on new debian 11 machine

### Miscellaneous Tasks

- Tests on NMVE erasures and bugfixes
- Add fixes with tests for Shred and NVMe erasures.

